TemplateFolderAndFile
Templates
GetCount
Count folders and files in a folder
User with a Get Count permission can access this method.
Request
GET /api/rp/v1/Templates/Folder/{id}/CountFolderAndFiles[?searchPattern&useRegex]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
|
| searchPattern | string | search pattern used to only include matching files in the count |
|
| useRegex | boolean | False | set this to true if you want to use regular expression to search |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
GetFoldersAndFiles
Get all folders and files from specified folder
User with a Get Entity permission can access this method.
Request
GET /api/rp/v1/Templates/Folder/{id}/ListFolderAndFiles[?skip&take&orderBy&desc&searchPattern&useRegex]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
|
| skip | integer | 0 | number of folder and files to skip |
| take | integer | 10 | number of folder and files to take |
| orderBy | a field to sort by |
||
| desc | boolean | False | if true - sorting will be done in the descending order, otherwise - ascending |
| searchPattern | string | search pattern used to only include matching files in the result |
|
| useRegex | boolean | False | set this to true if you want to use regular expression to search |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Provided parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Subscription or folder not found |
GetFoldersAndFilesGlobal
Get all folders and files from specified and children folders
User with a Get Entity permission can access this method.
Request
GET /api/rp/v1/Templates/Folder/{id}/ListFolderAndFiles/Global[?searchPattern&skip&take&orderBy&desc&deleted&useRegex]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
|
| searchPattern | string | ||
| skip | integer | 0 | number of folder and files, that have to be skipped |
| take | integer | 10 | number of folder and files, that have to be returned |
| orderBy | indicates a field to sort by |
||
| desc | boolean | False | indicates if sorting is descending |
| deleted | Deleted, NotDeleted, All |
||
| useRegex | boolean | False |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Returns list of the files from a specified folder |
|
| 400 | Params are not valid |
|
| 402 | Payment required, subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Subscription or folder not found |
GetRecycleBinFoldersAndFiles
Get all folders and files from recycle bin
User with a Get DeletedFiles permission can access this method.
Request
GET /api/rp/v1/Templates/{subscriptionId}/ListRecycleBinFolderAndFiles[?skip&take&orderBy&desc&searchPattern&useRegex]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | subscription id |
|
| skip | integer | 0 | number of folder and files to skip |
| take | integer | 10 | number of folder and files to take |
| orderBy | a field to sort by |
||
| desc | boolean | False | if true - sorting will be done in the descending order, otherwise - ascending |
| searchPattern | string | search pattern used to only include matching files in the recycle bin |
|
| useRegex | boolean | False | set this to true if you want to use regular expression to search |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Provided parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Subscription or folder not found |
CountRecycleBinFoldersAndFiles
Count all folders and files from recycle bin
User with a Get DeletedFiles permission can access this method.
Request
GET /api/rp/v1/Templates/{subscriptionId}/CountRecycleBinFolderAndFiles[?searchPattern&useRegex]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | subscription id |
|
| searchPattern | string | search pattern used to only include matching files in the recycle bin count |
|
| useRegex | boolean | False | set this to true if you want to use regular expression to search |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Provided parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Subscription not found |
ClearRecycleBin
Delete all folders and files from recycle bin
User with a Delete RecycleBin permission can access this method.
Request
DELETE /api/rp/v1/Templates/{subscriptionId}/ClearRecycleBin
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | subscription id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Provided parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Subscription not found |
RecoverAllFromRecycleBin
Recover all folders and files from recycle bin
User with a Create RecycleBin permission can access this method.
Request
POST /api/rp/v1/Templates/{subscriptionId}/RecoverRecycleBin
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | subscription id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Provided parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Subscription not found |
DeleteFiles
Delete folders and files from a folder or the recycle bin
User with a Delete permission can access this method.
Request
POST /api/rp/v1/Templates/{subscriptionId}/DeleteFiles
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | id of the subscription |
|
| body | File selection VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
RecoverFiles
Recover folders and files from the recycle bin
User with a SubscriptionCreate permission can access this method.
Request
POST /api/rp/v1/Templates/{subscriptionId}/RecoverFiles
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | id the subscription |
|
| body | File selection VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
MoveFilesToBin
Move folders and files to the recycle bin
User with a Delete Entity permission can access this method.
Request
POST /api/rp/v1/Templates/{subscriptionId}/ToBin
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | id of the subscription |
|
| body | File selection VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
CopyFiles
Copy folders and files to a specified folder
User with a Get permission for a files and Create permission for a destination folder can access this method.
Request
POST /api/rp/v1/Templates/{subscriptionId}/CopyFiles
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | id of current subscription |
|
| body | File selection VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
MoveFiles
Move folders and files to a specified folder
User with a Update Place permission for a files and Create permission for a destination folder can access this method.
Request
POST /api/rp/v1/Templates/{subscriptionId}/MoveFiles
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | id of current subscription |
|
| body | File selection VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Folder or subscription not found |
Definitions
CountVM
| Name | Type | Notes |
|---|---|---|
| count | integer (int64) | |
| $t | string |
ProblemDetails
| Name | Type | Notes |
|---|---|---|
| type | string | |
| title | string | |
| status | integer (int32) | |
| detail | string | |
| instance | string |
FilesVM
| Name | Type | Notes |
|---|---|---|
| $t | string | |
| files |
|
|
| count | integer (int64) | |
| skip | integer (int32) | |
| take | integer (int32) |
FileVM
| Name | Type | Notes |
|---|---|---|
| id | string | |
| createdTime | string (date-time) | |
| creatorUserId | string | |
| editedTime | string (date-time) | |
| editorUserId | string | |
| name | string | |
| parentId | string | |
| tags | array | |
| icon | string (byte) | |
| type |
|
|
| size | integer (int64) | |
| subscriptionId | string | |
| status |
|
|
| statusReason |
|
|
| errorMessage | string | |
| isDeleted | boolean | |
| platform |
|
|
| $t | string |
FileType
Enum Values
FileFolder
FileStatus
Enum Values
NoneInQueue
InProcess
Success
Failed
FileStatusReason
Enum Values
NoneAllRight
Hang
Error
NotFound
NotEnoughSpace
ExportStarted
PreparationStarted
CrashLoop
ReportPlatform
Enum Values
UnknownNET
VCL
SelectedFilesVM
| Name | Type | Notes |
|---|---|---|
| isAllSelected | boolean | |
| folderId | string | |
| searchPattern | string | |
| useRegex | boolean | |
| files | array | |
| folders | array | |
| path | string | |
| isBin | boolean | |
| $t | string |